@@ -71,7 +71,7 @@ class ScmGui:
         self.issues = None
         self.scm = None
         self.gotdata = False
-        self.thread = None
+        self.thread = False
         self.grouping = None
         self.reports = None
         self.menus = []
@@ -167,6 +167,10 @@ class ScmGui:
         cmd.add_command(label=label, command=self.fix_search, state=DISABLED)
         self.menus.append([cmd, label])
 
+        label = "Update SE Categories"
+        cmd.add_command(label=label, command=self.fix_secat, state=DISABLED)
+        self.menus.append([cmd, label])
+
         menubar.add_cascade(label="Edit", menu=cmd)
 
         cmd = Menu(menubar, tearoff=0)
@@ -259,14 +263,15 @@ class ScmGui:
         return True
 
     def open_archive(self):
-        """Open Archive file."""
+        """Open archive file."""
         if self.thread:
             return  # already running
 
         if self.scm_init() is False:
             return
 
-        self.thread = AnalysisThread(self, True).start()
+        self.thread = True
+        AnalysisThread(self, True).start()
 
     def swim_england(self):
         """Process Swim England File."""
@@ -312,7 +317,8 @@ class ScmGui:
         if self.prep_report(False) is False:
             return
 
-        self.thread = SwimEnglandThread(self).start()
+        self.thread = True
+        SwimEnglandThread(self).start()
 
     def facebook(self):
         """Window for reports."""
@@ -322,7 +328,8 @@ class ScmGui:
         if self.prep_report(False) is False:
             return
 
-        self.thread = FacebookThread(self).start()
+        self.thread = True
+        FacebookThread(self).start()
 
     def confirm(self):
         """Confirm email Report."""
@@ -384,7 +391,8 @@ class ScmGui:
         if self.thread:
             return  # already running
 
-        self.thread = UpdateThread(self).start()
+        self.thread = True
+        UpdateThread(self).start()
 
     def analyse_window(self):
         """Window for analysis result."""
@@ -394,7 +402,8 @@ class ScmGui:
         if self.scm_init() is False:
             return
 
-        self.thread = AnalysisThread(self, False).start()
+        self.thread = True
+        AnalysisThread(self, False).start()
 
     def analyse_enter(self, event):
         """Window for analysis result."""
@@ -410,7 +419,20 @@ class ScmGui:
             messagebox.showerror("Error", "Analyse data first, before fixing (2)")
             return
 
-        self.thread = SearchThread(self).start()
+        self.thread = True
+        SearchThread(self).start()
+
+    def fix_secat(self):
+        """Window for reports."""
+        if self.thread:
+            return  # already running
+
+        if self.gotdata is False:
+            messagebox.showerror("Error", "Analyse data first, before fixing (3)")
+            return
+
+        self.thread = True
+        SecatThread(self).start()
 
     def fixit(self):
         """Window for reports."""
@@ -441,7 +463,8 @@ class ScmGui:
         if self.scm_init() is False:
             return
 
-        self.thread = BackupThread(self).start()
+        self.thread = True
+        BackupThread(self).start()
 
     def clear_data(self):
         """Prepare to rerun."""
@@ -596,10 +619,8 @@ class ScmGui:
         if self.thread:
             return  # already running
 
-        if self.scm_init() is False:
-            return
-
-        self.thread = RecordThread(self, newtimes).start()
+        self.thread = True
+        RecordThread(self, newtimes).start()
 
 
 class AnalysisThread(threading.Thread):
@@ -641,23 +662,23 @@ class AnalysisThread(threading.Thread):
             if wrap(None, self.scm.decrypt, where) is False:
                 messagebox.showerror("Error", f"Cannot read from archive: {where}")
                 self.gui.master.after(AFTER, self.gui.set_normal)
-                self.gui.thread = None
+                self.gui.thread = False
                 return
         else:
             if wrap(None, self.scm.get_data, False) is False:
                 messagebox.showerror("Analysis", "Failed to read data")
                 self.gui.master.after(AFTER, self.gui.set_normal)
-                self.gui.thread = None
+                self.gui.thread = False
                 return
 
         if wrap(10, self.scm.linkage) is False:
             self.gui.master.after(AFTER, self.gui.set_normal)
-            self.gui.thread = None
+            self.gui.thread = False
             return
 
         if wrap(10, self.scm.analyse) is False:
             self.gui.master.after(AFTER, self.gui.set_normal)
-            self.gui.thread = None
+            self.gui.thread = False
             return
 
         self.gui.gotdata = True
@@ -678,7 +699,7 @@ class AnalysisThread(threading.Thread):
         self.gui.issue_window.lift()
         self.gui.master.after(AFTER, self.gui.set_normal)
 
-        self.gui.thread = None
+        self.gui.thread = False
 
         debug("Analyse Thread complete, result posted", 8)
 
@@ -710,7 +731,7 @@ class BackupThread(threading.Thread):
         self.gui.master.update_idletasks()
         self.gui.master.after(AFTER, self.gui.set_normal)
 
-        self.gui.thread = None
+        self.gui.thread = False
 
 
 class FacebookThread(threading.Thread):
@@ -724,7 +745,6 @@ class FacebookThread(threading.Thread):
 
     def run(self):
         """Process a Facebook report."""
-
         fbook = Facebook()
         if wrap(None, fbook.read_data, self.scm) is False:
             messagebox.showerror("Error", "Could not read facebook files")
@@ -745,6 +765,8 @@ class FacebookThread(threading.Thread):
         self.gui.notify_text.config(state=DISABLED)
         self.gui.report_window.lift()
 
+        self.gui.thread = False
+
 
 class RecordThread(threading.Thread):
     """Thread for Records."""
@@ -791,6 +813,7 @@ class RecordThread(threading.Thread):
             return
 
         self.gui.notify_text.config(state=DISABLED)
+        self.gui.thread = False
 
 
 class SwimEnglandThread(threading.Thread):
@@ -813,6 +836,7 @@ class SwimEnglandThread(threading.Thread):
         self.gui.report_text.config(state=DISABLED)
         self.gui.notify_text.config(state=DISABLED)
         self.gui.report_window.lift()
+        self.gui.thread = False
 
 
 class UpdateThread(threading.Thread):
@@ -836,7 +860,7 @@ class UpdateThread(threading.Thread):
         self.gui.master.update_idletasks()
         self.gui.master.after(AFTER, self.gui.set_normal)
 
-        self.gui.thread = None
+        self.gui.thread = False
 
 
 class SearchThread(threading.Thread):
@@ -850,7 +874,6 @@ class SearchThread(threading.Thread):
 
     def run(self):
         """Run analyser."""
-
         self.gui.set_buttons(DISABLED)
 
         if wrap(None, self.scm.fix_search) is False:
@@ -859,6 +882,29 @@ class SearchThread(threading.Thread):
             return
 
         self.gui.set_buttons(NORMAL)
+        self.gui.thread = False
+
+
+class SecatThread(threading.Thread):
+    """Thread to run SE Catagories."""
+
+    def __init__(self, gui):
+        """Initialise."""
+        threading.Thread.__init__(self)
+        self.gui = gui
+        self.scm = gui.scm
+
+    def run(self):
+        """Run analyser."""
+        self.gui.set_buttons(DISABLED)
+
+        if wrap(None, self.scm.fix_secat) is False:
+            messagebox.showerror("Error", "fix SE Category error")
+            self.gui.set_buttons(NORMAL)
+            return
+
+        self.gui.set_buttons(NORMAL)
+        self.gui.thread = False
 
 
 class Edit(Frame):  # pylint: disable=too-many-ancestors
@@ -896,7 +942,7 @@ class Edit(Frame):  # pylint: disable=too-many-ancestors
         self.text_pad = scrolledtext.ScrolledText(top_group, width=80, height=40)
         self.text_pad.grid(row=0, column=0, sticky=NSEW)
 
-        with open(self.file, FILE_READ) as file:
+        with open(self.file, FILE_READ, encoding="utf8") as file:
             contents = file.read()
             self.text_pad.insert("1.0", contents)
             file.close()
@@ -918,7 +964,7 @@ class Edit(Frame):  # pylint: disable=too-many-ancestors
 
     def save_command(self):
         """Save."""
-        with open(self.file, FILE_WRITE) as file:
+        with open(self.file, FILE_WRITE, encoding="utf8") as file:
             # slice off the last character from get, as an extra return is added
             data = self.text_pad.get("1.0", END)
             file.write(data)
