@@ -50,6 +50,11 @@ E_COACH_WITH_SESSIONS = {
     MESSAGE: "Coach with swim sessions in profile",
     REVERSE: False,
     REPORT: R_COACH}
+E_CATEGORY = {
+    NAME: "E_CATEGORY",
+    MESSAGE: "Unknown SE Category",
+    REVERSE: False,
+    REPORT: R_MEMBER}
 E_COACH_ROLE = {
     NAME: "E_COACH_ROLE",
     MESSAGE: "In coach role, but not a coach",
@@ -424,7 +429,6 @@ HANDLER = None
 
 def issue(xobject, error, msg=None, level=0, msg2=""):
     """Record an issue."""
-
     debug(f"ISSUE: {xobject.name}, {error[MESSAGE]} / {msg}", 5)
 
     if level != -1:
@@ -468,7 +472,10 @@ def debug_trace(level):
     """Decorator to provide a trace capability."""
 
     def wrap(func):
+        """The wrapper..."""
+
         def wrapped_f(self, *args):
+            """The wrapped..."""
             name = func.__name__
             xclass = self.__class__.__name__
             xtime = datetime.now().time()
@@ -568,27 +575,27 @@ class IssueHandler:
     def confirm_email(self):
         """Print email addresses for confirmation errors."""
         matrix = {}
-        for anissue in self.by_error:
-            for anerror in self.by_error[anissue]:
-                pkg = self.by_error[anissue][anerror]
-                for line in pkg:
-                    _, _, report, _, entity = line
-                    if report == R_CONFIRMATION:
-                        key = "Other"
-                        if entity.is_parent:
-                            key = "parent"
-                        if entity.is_polo:
-                            key = "polo"
-                        if entity.is_synchro:
-                            key = "synchro"
-                        if entity.is_swimmer:
-                            key = "swimmer"
-                        if key in matrix:
-                            matrix[key].append(entity)
-                        else:
-                            matrix[key] = [entity]
+        # If errors, check history - big pylint change
+        for pkg in self.by_error.values():
+            for line in pkg:
+                _, _, report, _, entity = line
+                if report == R_CONFIRMATION:
+                    key = "Other"
+                    if entity.is_parent:
+                        key = "parent"
+                    if entity.is_polo:
+                        key = "polo"
+                    if entity.is_synchro:
+                        key = "synchro"
+                    if entity.is_swimmer:
+                        key = "swimmer"
+                    if key in matrix:
+                        matrix[key].append(entity)
+                    else:
+                        matrix[key] = [entity]
 
         res = ""
+        # pylint: disable=consider-using-dict-items
         for msg in matrix:
             res += f"{msg}: \n"
             for entity in matrix[msg]:
