@@ -22,6 +22,7 @@ Where <options> are:
    --backup = backup
    --coaches = report of coaches per session
    --confirm_email = print email addresses for confirm errors
+   --covid = print a list of sessions with who has replied to the Covid declaration
    --csv <csvfile> = read and validate file
    --dump <type> = dump entities of <type>
    --error = print sorted by error
@@ -41,6 +42,7 @@ Where <options> are:
    --report <report> = which reports to run
    --restore <type> = restore an entity of <type> (need -archive as well)
    --se = Check against SE database
+   --sessions = print a list of swimmers and their sessions in CSV format
    --to <email> = Who to send the emial to (used with --email)
    --verify <date> = use archive backup
 
@@ -55,6 +57,7 @@ LONG_OPTS = [
     "backup",
     "coaches",
     "confirm_email",
+    "covid",
     "csv=",
     "dump=",
     "email",
@@ -74,6 +77,7 @@ LONG_OPTS = [
     "report=",
     "restore=",
     "se",
+    "sessions",
     "to=",
     "verify=",
 ]
@@ -244,6 +248,22 @@ def cmd(argv=None):
 
     scm.analyse()
 
+    if scm.option("--covid"):
+        output = scm.sessions.print_swimmers_covid()
+        if scm.option("--email"):
+            send_email(scm, output, "SCM: Session / Covid Report")
+        else:
+            print(output)
+        sys.exit()
+
+    if scm.option("--sessions"):
+        output = scm.members.print_swimmers_sessions()
+        if scm.option("--email"):
+            send_email(scm, output, "SCM: Swimmers Per Session Report")
+        else:
+            print(output)
+        sys.exit()
+
     if scm.option("--lists"):
         if scm.option("--verify"):
             print("--lists can only be used with live data")
