@@ -1,4 +1,5 @@
 """SCM Members."""
+# pylint: disable=too-many-lines
 import datetime
 import re
 
@@ -12,6 +13,7 @@ from scm_helper.config import (
     A_FIRSTNAME,
     A_GUID,
     A_ISCOACH,
+    A_ISMASTER,
     A_ISPARENT,
     A_ISVOLUNTEER,
     A_KNOWNAS,
@@ -40,6 +42,7 @@ from scm_helper.config import (
     C_TYPES,
     CTYPE_COACH,
     CTYPE_COMMITTEE,
+    CTYPE_MASTER,
     CTYPE_PARENT,
     CTYPE_POLO,
     CTYPE_SWIMMER,
@@ -54,6 +57,7 @@ from scm_helper.config import (
 )
 from scm_helper.entity import Entity, get_date, print_all
 from scm_helper.issue import (
+    E_CATEGORY,
     E_CONFIRMATION_EXPIRED,
     E_DATE,
     E_DBS_EXPIRED,
@@ -92,6 +96,35 @@ A_DBS_RENEWAL_DATE = "DBSRenewalDate"
 A_SAFEGUARDING_RENEWAL_DATE = "SafeguardingRenewalDate"
 A_SWIMMERS = "Swimmers"
 
+CAT_MAPPING = {
+    "1": "Club Train",
+    "2": "Club Compete",
+    "3": "Club Support",
+    "CAT 1": "Club Train",
+    "CAT 2": "Club Compete",
+    "CAT 3": "Club Support",
+    "Train": "Club Train",
+    "Compete": "Club Compete",
+    "Support": "Club Support",
+    "train": "Club Train",
+    "compete": "Club Compete",
+    "support": "Club Support",
+    "club train": "Club Train",
+    "club compete": "Club Compete",
+    "club support": "Club Support",
+    "club Train": "Club Train",
+    "club Compete": "Club Compete",
+    "club Support": "Club Support",
+    "Club train": "Club Train",
+    "Club compete": "Club Compete",
+    "Club support": "Club Support",
+}
+CAT_VALID = [
+    "Club Train",
+    "Club Compete",
+    "Club Support",
+]
+
 
 class Member(Entity):
     """A member."""
@@ -251,7 +284,7 @@ class Member(Entity):
         return False
 
     def get_conduct_name(self, find):
-        """get a code of conduct."""
+        """Get a code of conduct."""
         for code in self._conduct:
             if find == code.name:
                 return code
@@ -436,6 +469,15 @@ class Member(Entity):
             fix["JobTitle"] = xtype.title()
             self.fixit(fix, f"Add jobtitle: {name}")
 
+    def check_category(self):
+        """Check the member categoty."""
+        cat = self.data[A_ASA_CATEGORY]
+        if cat == "":
+            return
+
+        if cat not in CAT_VALID:
+            issue(self, E_CATEGORY, cat)
+
     @debug_trace(5)
     def analyse(self):
         """Analyse the member."""
@@ -462,6 +504,10 @@ class Member(Entity):
             self.check_type(CTYPE_SWIMMER)
             found = True
 
+        if self.is_master:
+            self.check_type(CTYPE_MASTER)
+            found = True
+
         if self.is_synchro:
             self.check_type(CTYPE_SYNCHRO)
             found = True
@@ -492,6 +538,9 @@ class Member(Entity):
             found = True
             self.check_type(CTYPE_COMMITTEE)
 
+        if A_ASA_CATEGORY in self.data:
+            self.check_category()
+
         if self.jobtitle:
             if (
                 (self.is_volunteer is not True)
@@ -546,6 +595,32 @@ class Member(Entity):
 
         return True
 
+    def fix_secat(self):
+        """fix_se categories."""
+
+        if A_ASA_CATEGORY not in self.data:
+            return False
+
+        cat = self.data[A_ASA_CATEGORY]
+
+        if cat in CAT_MAPPING:
+
+            self.newdata = {}
+            self.newdata[A_GUID] = self.guid
+
+            notify(f"Modify Category for {self.name} to {CAT_MAPPING[cat]}...")
+
+            self.newdata[A_ASA_CATEGORY] = CAT_MAPPING[cat]
+
+            res = self.scm.api_write(self, False)
+            if res is False:
+                notify("Hit a snag!\n")
+                return False
+
+            notify("Success.\n")
+
+        return True
+
     def add_group(self, group):
         """Add a group to the swimmer."""
         debug(f"Added {self.name} to {group.name}", 9)
@@ -836,6 +911,14 @@ class Member(Entity):
             return True
         return False
 
+    @property
+    def is_master(self):
+        """Is it a Master."""
+        isa = self.check_attribute(A_ISMASTER)
+        if isa == "1":
+            return True
+        return False
+
     @property
     def is_parent(self):
         """Is it a swimmer."""
