@@ -85,6 +85,7 @@ class Members(Entities):
             self.knownas[data.knownas] = data
             if data.asa_number:
                 self.by_asa[data.asa_number] = data
+
             if data.facebook:
                 for face in data.facebook:
                     self.facebook[face] = data
@@ -127,6 +128,14 @@ class Members(Entities):
             # TODO remove when API fixed.
             member.linkage2()
 
+    def fix_secat(self):
+        """fix_se categories."""
+        for member in self.entities:
+            res = member.fix_secat()
+            if res is False:
+                return False
+        return True
+
     def fix_search(self):
         """fix_search_index."""
         for member in self.entities:
